%define module	virtualenv

Name:		python-%{module}
Version:	16.7.10
Release:	%mkrel 1
Summary:	Virtual Python Environment builder
Group:		Development/Python
License:	MIT
URL:		https://pypi.python.org/pypi/virtualenv
Source0:	https://pypi.python.org/packages/source/v/virtualenv/%{module}-%{version}.tar.gz

# Add /usr/share/python-wheels to file_search_dirs
Patch2:		rpm-wheels.patch

BuildArch:	noarch
BuildRequires:	git-core
BuildRequires:	python3-devel
BuildRequires:	python3-setuptools

# doc
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(towncrier)

# RPM installed wheels
BuildRequires:	python-pip-wheel
BuildRequires:	python-setuptools-wheel
BuildRequires:	python-wheel-wheel

%description
virtualenv is a tool to create isolated Python environments.

%package -n	python3-%{module}
Summary:	Tool to create isolated Python 3 environments
Group:		Development/Python
Requires:	python3-devel
Requires:	python3dist(setuptools)
Requires:	python3-pkg-resources
%{?python_provide:%python_provide python3-virtualenv}
Provides:	virtualenv = %{version}-%{release}

Conflicts:	python2-virtualenv < 16.1.0

# RPM installed wheels
Requires:	python-pip-wheel
Requires:	python-setuptools-wheel
Requires:	python-wheel-wheel

%description -n python3-%{module}
virtualenv is a tool to create isolated Python 3 environments. virtualenv
is a successor to workingenv, and an extension of virtual-python. It is
written by Ian Bicking, and sponsored by the Open Planning Project. It is
licensed under an MIT-style permissive license

%prep
%setup -q -n %{module}-%{version}
%autopatch -p1

%{__sed} -i -e "1s|#!/usr/bin/env python||" virtualenv.py

# Remove the wheels provided by RPM packages
rm -rf src/virtualenv_support/pip-*.whl
rm -rf src/virtualenv_support/setuptools-*.whl
rm -rf src/virtualenv_support/wheel-*.whl

%build
%py3_build

# docs
%{__python3} setup.py build_sphinx
rm -f build/sphinx/html/.buildinfo

%install
%py3_install

%files -n python3-%{module}
%doc PKG-INFO AUTHORS.txt LICENSE.txt
%doc build/sphinx/*
%{_bindir}/virtualenv
%{python3_sitelib}/*


%changelog
* Tue Mar 31 2020 daviddavid <daviddavid> 16.7.10-1.mga8
+ Revision: 1562577
- new version: 16.7.10

* Thu Feb 20 2020 umeabot <umeabot> 16.7.9-2.mga8
+ Revision: 1546134
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 shlomif <shlomif> 16.7.9-1.mga8
+ Revision: 1486147
- New version 16.7.9

* Sat Sep 07 2019 wally <wally> 16.7.5-1.mga8
+ Revision: 1438178
- new version 16.7.5
- sync patches with Fedora
- drop python2 support
- rebuild for python3.8

* Mon Jan 07 2019 wally <wally> 16.1.0-3.mga7
+ Revision: 1350665
- rebuild for python3.7

* Tue Jan 01 2019 wally <wally> 16.1.0-2.mga7
+ Revision: 1348272
- require python-wheel-wheel
- require python-setuptools-wheel

* Tue Jan 01 2019 wally <wally> 16.1.0-1.mga7
+ Revision: 1348183
- new version 16.1.0
- add rediffed patches from Fedora
- default to python3

* Fri Sep 21 2018 umeabot <umeabot> 15.2.0-2.mga7
+ Revision: 1290457
- Mageia 7 Mass Rebuild

* Sun Apr 01 2018 kekepower <kekepower> 15.2.0-1.mga7
+ Revision: 1214056
- Update to version 15.2.0

* Thu Mar 22 2018 pterjan <pterjan> 15.1.0-3.mga7
+ Revision: 1211303
- Fix summary and obsoletes

* Mon Feb 26 2018 daviddavid <daviddavid> 15.1.0-2.mga7
+ Revision: 1205329
- fix requires

* Tue Feb 20 2018 kekepower <kekepower> 15.1.0-1.mga7
+ Revision: 1203714
- Added BR for python2-typing
- Update to version 15.1.0
- Rename python-virtualenv to python2-virtualenv

* Sat Aug 05 2017 pterjan <pterjan> 13.1.2-3.mga7
+ Revision: 1135681
- Rebuild for python 3.6

* Sat Feb 20 2016 umeabot <umeabot> 13.1.2-2.mga6
+ Revision: 972467
- Mageia 6 Mass Rebuild

* Sun Nov 08 2015 philippem <philippem> 13.1.2-1.mga6
+ Revision: 898708
- update to 13.1.2, add Python3

* Tue Apr 28 2015 philippem <philippem> 12.1.1-2.mga5
+ Revision: 820818
- update to 12.1.1 fix mga#15748

* Wed Oct 15 2014 umeabot <umeabot> 1.11.6-5.mga5
+ Revision: 745816
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.11.6-4.mga5
+ Revision: 729961
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.11.6-3.mga5
+ Revision: 688408
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 philippem <philippem> 1.11.6-2.mga5
+ Revision: 632670
- revert to Python 2.7 by default to not break firefox, thunderbird, iceape and wine-gecko builds

* Tue Jun 03 2014 philippem <philippem> 1.11.6-1.mga5
+ Revision: 632664
- update to 1.11.6, Python 3.4 by default
+ pterjan <pterjan>
- Rebuild for new Python

* Sun Dec 01 2013 philippem <philippem> 1.10.1-6.mga4
+ Revision: 554548
- change-match_hostname-to-follow-RFC-6125 (mga#11785)

* Tue Oct 22 2013 umeabot <umeabot> 1.10.1-5.mga4
+ Revision: 544426
- Mageia 4 Mass Rebuild

* Mon Oct 21 2013 philippem <philippem> 1.10.1-4.mga4
+ Revision: 539206
- fix inc_dir

* Tue Oct 15 2013 pterjan <pterjan> 1.10.1-3.mga4
+ Revision: 499706
- Rebuild to add different pythonegg provides for python 2 and 3

* Fri Sep 06 2013 philippem <philippem> 1.10.1-2.mga4
+ Revision: 475526
- bump release to have clean upgrade path from mga3 after the upgrade for security reason in mga2 and mga3

* Thu Aug 08 2013 philippem <philippem> 1.10.1-1.mga4
+ Revision: 464597
- Update to 1.10.1

* Mon Jul 29 2013 philippem <philippem> 1.10-1.mga4
+ Revision: 460644
- Update to 1.10

* Mon Jun 03 2013 kharec <kharec> 1.9.1-1.mga4
+ Revision: 436201
- New version 1.9.1
- Drop P0, it was applied upstream

* Sun Jan 13 2013 umeabot <umeabot> 1.7.1.2-4.mga3
+ Revision: 379674
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 23 2012 lebedov <lebedov> 1.7.1.2-3.mga3
+ Revision: 296929
- Remove python-devel install requirement (#4481).

* Fri Aug 03 2012 tv <tv> 1.7.1.2-2.mga3
+ Revision: 278204
- better upstream fix for multiarch (fix firefox15 build)

* Tue May 29 2012 lebedov <lebedov> 1.7.1.2-1.mga3
+ Revision: 249516
- Update to 1.7.1.2.
  Don't set PYTHONDONTWRITEBYTECODE (#3358).

* Wed Nov 30 2011 lebedov <lebedov> 1.7-1.mga2
+ Revision: 174425
- Update to 1.7.

* Mon Sep 26 2011 lebedov <lebedov> 1.6.4-2.mga2
+ Revision: 148995
- imported package python-virtualenv

